agentle.mcp.session\_management.redis
=====================================

.. automodule:: agentle.mcp.session_management.redis

   
   .. rubric:: Functions

   .. autosummary::
   
      cast
   
   .. rubric:: Classes

   .. autosummary::
   
      Any
      RedisSessionManager
      SessionManager
   